------------------------------------------------------------------------
--	PmodAMP1.vhd  --  Overall Project Controller Module
------------------------------------------------------------------------
-- Author: Michelle Yu
--	Copyright 2011 Digilent, Inc.
------------------------------------------------------------------------
-- Module description
--		This is a demo project for the PmodAMP1. 
--		This Project outputs a middle C when it is in used with a Nexys3 board. 
--		For any other board, the note might vary due to different clock frequency.
--
--
--  Inputs:
--		CLK				100MHz onboard system clock
--
--  Outputs:
--		JA				pin 1 and 3 of connector JA 
--
------------------------------------------------------------------------
-- Revision History:
--
--	08/16/2011(Michelle Yu): created
--
------------------------------------------------------------------------




library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity PmodAMP1 is
	port( clk:in std_logic;
			JA : inout  STD_LOGIC_VECTOR(3 downto 0) -- PmodAMP1 is designed to be plug in on JA
		  );
end PmodAMP1;

architecture behavioral of PmodAMP1 is	

	component synth is
	port(clk : in std_logic;
		  syn_out : inout std_logic_vector(7 downto 0));
	end component;

	component sinerom is
    Port ( addr : in std_logic_vector(7 downto 0);
           sin : out std_logic_vector(7 downto 0));
	end component;
	
	component PWM is
    Port ( ck : 	in  STD_LOGIC; 		--clock input
           cmpPwm : 	in  STD_LOGIC_VECTOR(7 downto 0); 	--switch input
           pwm_out : 	out  STD_LOGIC	--pwm_out output
			 );
	end component;
	
	signal syno, sino:std_logic_vector(7 downto 0);
	
begin
	C0 : synth port map ( clk=>clk, syn_out=> syno);
	C1 : sinerom port map(addr => syno, sin => sino);
   C2 : PWM port map(ck => clk, cmpPwm=>sino, pwm_out =>JA(0));
	-- assign JA2 so that the note will play on both right and left outputs
	JA(2) <= JA(0);
	
	
end behavioral;

