------------------------------------------------------------------------
--	synth.vhd  --  clock divider
------------------------------------------------------------------------
-- Author: Michelle Yu
--	Copyright 2011 Digilent, Inc.
------------------------------------------------------------------------
-- Module description
--		This file divides the clock to a lower frequency
--		so that PmodAMP1 could output a middle C
--
--
--  Inputs:
--		CLK				100MHz onboard system clock
--
--  Outputs:
--		syn_out			a value between 0 and 255
--
------------------------------------------------------------------------
-- Revision History:
--
--	08/16/2011(Michelle Yu): created
--
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;



entity synth is
	port(clk : in std_logic;
		  syn_out : inout std_logic_vector(7 downto 0));
end synth;

architecture Behavioral of synth is

signal sclk : std_logic_vector(10 downto 0);
	
begin
	process(clk)
		begin 
			if clk'event and clk = '1' then
			-- divide a clock by "10111010101" (1493) which is about the value of 100M/256/261.6
			-- where 100M is the clock frequency on a Nexys3
			-- 256 is the number of points in the sine wave table
			-- 261.6 is the frequency of a middle C
				if sclk = "10111010101" then 
					--"11111111" is 255 is the maximum point in the sine wave table
					if syn_out < "11111111" then 
						syn_out <= syn_out + 1;
					else
						syn_out <= "00000000";
					end if;
					sclk <= "00000000000";
				else
					sclk <= sclk + 1;
				end if;
			end if;
	end process;

end Behavioral;

